Learn R Programming

arabicStemR (version 1.2)

arabicStemR-package:

Description

This package is a stemmer for texts in Arabic, as part of the txtorg utility for text analysis workflow. The stemmer is loosely based on the light 10 stemmer, but with a number of modifications.

Arguments

Details

Use the stem function.

See Also

stem

Examples

Run this code
# Load data

data(aljazeera)

## stem and transliterate the results
stem(aljazeera)

## stem and return the stemlist
out <- stem(aljazeera,returnStemList=TRUE)
out$text
out$stemlist

Run the code above in your browser using DataLab