Usage
removeSuffixes(texts, x1 = 4, x2 = 4, x3 = 4, x4 = 4,
x5 = 4, x6 = 4, x7 = 4, x8 = 3, x9 = 3, x10 = 3,
dontstem = c('\u0627\u0644\u0644\u0647','u0644\u0644\u0647'))Arguments
texts
An Arabic-language string in unicode.
x1
The number of letters that must remain in a word for the function to remove the suffix "ha-alif".
x2
The number of letters that must remain in a word for the function to remove the suffix "alif-nun".
x3
The number of letters that must remain in a word for the function to remove the suffix "alif-ta".
x4
The number of letters that must remain in a word for the function to remove the suffix "waw-nun".
x5
The number of letters that must remain in a word for the function to remove the suffix "yah-nun".
x6
The number of letters that must remain in a word for the function to remove the suffix "yah-heh".
x7
The number of letters that must remain in a word for the function to remove the suffix "yah-ta marbutta".
x8
The number of letters that must remain in a word for the function to remove the suffix "heh".
x9
The number of letters that must remain in a word for the function to remove the suffix "ta marbutta".
x10
The number of letters that must remain in a word for the function to remove the suffix "yah".
dontstem
Words that should not be stemmed (entered in unicode).