This package is a stemmer for texts in Arabic, as part of the txtorg utility for text analysis workflow. The stemmer is loosely based on the light 10 stemmer, but with a number of modifications.
# Load data
data(aljazeera)
## stem and transliterate the resultsstem(aljazeera)
## stem and return the stemlistout <- stem(aljazeera,returnStemList=TRUE)
out$text
out$stemlist