Usage
removePrefixes(texts, x1 = 4, x2 = 4, x3 = 5, x4 = 5, x5 = 5, x6 = 5, x7 = 4,
dontstem = c('\u0627\u0644\u0644\u0647','u0644\u0644\u0647'))Arguments
texts
An Arabic-language string in unicode
x1
The number of letters that must remain in a word for the function to remove the prefix "waw".
x2
The number of letters that must remain in a word for the function to remove the prefix "alif-lam".
x3
The number of letters that must remain in a word for the function to remove the prefix "waw-alif-lam".
x4
The number of letters that must remain in a word for the function to remove the prefix "ba-alif-lam".
x5
The number of letters that must remain in a word for the function to remove the prefix "kaf-alif-lam".
x6
The number of letters that must remain in a word for the function to remove the prefix "fa-alif-lam".
x7
The number of letters that must remain in a word for the function to remove the prefix "lam-lam".
dontstem
Words that should not be stemmed (entered in unicode).